# Bookkeeping App

一个基于 Jetpack Compose 开发的现代化记账应用。

## 项目概述

本项目是一个使用 Kotlin 和 Jetpack Compose 开发的 Android 记账应用，采用 MVVM 架构，提供简洁直观的用户界面和丰富的记账功能。

## 主要特性

- 💰 收入/支出记录管理
- 👥 成员管理系统
- 📊 分类管理系统
- 📅 自定义日期选择器
- 📈 月度统计视图
- 🎨 Material 3 设计风格

## 技术栈

- 开发语言：Kotlin
- UI 框架：Jetpack Compose
- 架构模式：MVVM
- 数据存储：Room Database
- 依赖注入：Hilt
- 异步处理：Kotlin Coroutines

## 开发计划

### 0. 基础功能 (已完成)
- [x] 收入/支出记录管理
- [x] 分类管理系统
  - [x] 默认分类
  - [x] 自定义分类
  - [x] 分类编辑/删除
- [x] 自定义日期选择器
- [x] Material 3 设计界面
- [x] 深色/浅色主题切换
- [x] 主题色自定义

### 1. 成员管理功能 (feature/member)
- [ ] 成员添加/编辑/删除
- [ ] 记账时选择相关成员
- [ ] 成员消费统计
- [ ] 成员间账单分摊

### 2. 数据统计与可视化 (feature/statistics)
- [ ] 支出/收入趋势图表
- [ ] 分类占比饼图
- [ ] 月度/年度报表

### 3. 数据导出与备份 (feature/backup)
- [ ] 导出 CSV/Excel 功能
- [ ] 云端备份支持
- [ ] 数据迁移工具

### 4. 预算管理 (feature/budget)
- [ ] 月度预算设置
- [ ] 预算超支提醒
- [ ] 分类预算管理

### 5. 用户体验优化 (feature/ux-enhancement)
- [x] 深色模式支持
- [ ] 手势操作优化
- [ ] 快速记账小组件
- [ ] 多语言支持

### 6. 性能优化 (feature/performance)
- [ ] 大数据量处理优化
- [ ] 启动速度优化
- [ ] 内存使用优化

## 分支管理

- `master`: 稳定主分支
- `develop`: 主开发分支
- `feature/*`: 功能开发分支
- `release/*`: 版本发布分支

## 版本历史

### v1.0.0
- ✨ 基础记账功能
  - 收入/支出记录
  - 金额、日期、分类、备注管理
- 🎨 Material 3 设计界面
  - 深色/浅色主题切换
  - 主题色自定义
- 📊 分类管理
  - 默认分类预设
  - 自定义分类支持
  - 分类编辑与删除
- 📅 月度统计
  - 月度收支总览
  - 月份快速切换
- 🗓️ 自定义日期选择器

## 贡献指南

欢迎提交 Issue 和 Pull Request 来帮助改进项目。

## 许可证

本项目采用 MIT 许可证。
